/*
 * Copyright (C) 2008, 2009 Ingo Luetkebohle <iluetkeb@techfak.uni-bielefeld.de>
 * Made available under the terms of the GNU General Public License v3
 */

package de.unibi.agai.xml;

import de.unibi.agai.xml.transport.TransportConversionException;
import de.unibi.agai.xml.*;
import nu.xom.Attribute;
import nu.xom.Element;
import nu.xom.Node;

/**
 *
 * @author ingo
 */
public class BaseTypeConverter {
    private final static TextSplice strSplice = new TextSplice();
    private final static LongConverter longConv = new LongConverter();
    private final static IntConverter intConv = new IntConverter();
    private final static DoubleConverter doubleConv = new DoubleConverter();
    private final static FloatConverter floatConv = new FloatConverter();
    private final static ValuePolicy<String> nonEmptyString = new NonEmptyString();

    protected final static ValuePolicy<String> nep(boolean nonEmpty) {
        return nonEmpty ? nonEmptyString : null;
    }

    public final static long asLong(Node n, boolean nonEmpty) throws TransportConversionException {
        return longConv.fromTransport(strSplice.extract(n, nep(nonEmpty)), null);
    }
    public final static int asInt(Node n, boolean nonEmpty) throws TransportConversionException {
        return intConv.fromTransport(strSplice.extract(n, nep(nonEmpty)), null);
    }
    public final static double asDouble(Node n, boolean nonEmpty) throws TransportConversionException {
        return doubleConv.fromTransport(strSplice.extract(n, nep(nonEmpty)), null);
    }
    public final static float asFloat(Node n, boolean nonEmpty) throws TransportConversionException {
        return floatConv.fromTransport(strSplice.extract(n, nep(nonEmpty)), null);
    }

    public final static void toLong(Attribute n, long data) {
        strSplice.assignTo(n, longConv.toTransport(data));
    }
    public final static void toInt(Attribute n, int data) {
        strSplice.assignTo(n, intConv.toTransport(data));
    }
    public final static void toDouble(Attribute n, double data) {
        strSplice.assignTo(n, doubleConv.toTransport(data));
    }
    public final static void toFloat(Attribute n, float data) {
        strSplice.assignTo(n, floatConv.toTransport(data));
    }
    // element-child assignments
    public final static void toLong(Element n, long data) {
        strSplice.assignTo(n, longConv.toTransport(data));
    }
    public final static void toInt(Element n, int data) {
        strSplice.assignTo(n, intConv.toTransport(data));
    }
    public final static void toDouble(Element n, double data) {
        strSplice.assignTo(n, doubleConv.toTransport(data));
    }
    public final static void toFloat(Element n, float data) {
        strSplice.assignTo(n, floatConv.toTransport(data));
    }
}
final class LongConverter extends StringConverter<Long> {
    @Override
    protected Long parse(String data) {
        return Long.parseLong(data);
    }
}
final class IntConverter extends StringConverter<Integer> {
    @Override
    protected Integer parse(String data) {
        return Integer.parseInt(data);
    }
}
final class DoubleConverter extends StringConverter<Double> {
    @Override
    protected Double parse(String data) {
        return Double.parseDouble(data);
    }
}
final class FloatConverter extends StringConverter<Float> {
    @Override
    protected Float parse(String data) {
        return Float.parseFloat(data);
    }
}
