/*
 * Copyright (C) 2008, 2009 Ingo Luetkebohle <iluetkeb@techfak.uni-bielefeld.de>
 * Made available under the terms of the GNU General Public License v3
 */

package de.unibi.agai.xml;

import de.unibi.agai.xml.transport.TransportConversionException;
import nu.xom.Attribute;
import nu.xom.Document;
import nu.xom.Element;
import nu.xom.Node;
import nu.xom.ParentNode;

/**
 * Assigns the value into an attribute of a particular Element. Will
 * create the Element as a child of the passed node, if necessary.
 *
 * @author iluetkeb
 */
public class ElementAttrSplice implements ValueSplice<String> {
    private final String elementName;
    private final String attrName;

    public ElementAttrSplice(String elementName, String attrName) {
        this.elementName = elementName;
        this.attrName = attrName;
    }

    public ParentNode assignTo(ParentNode n, String o) {
        // skip document element
        if(n instanceof Document)
            n = ((Document)n).getRootElement();
        Element e = (Element)n;
        // check if we're on the right node already. if not,
        // check if a matching child is present. if yes, use it,
        // otherwise create it.
        if(!e.getLocalName().equals(elementName)) {
            Element ne = e.getFirstChildElement(elementName);
            if(ne == null) {
                ne = new Element(elementName);
                e.appendChild(ne);
            }
            e = ne;
        }
        // assign value as attribute
        e.addAttribute(new Attribute(attrName, o));
        return e;
    }

    public void assignTo(Attribute a, String o) {
        a.setValue(o);
    }

    public String extract(Node n, ValuePolicy<String> vp) throws TransportConversionException {
        String result;
        if(n instanceof Attribute) {
            result = n.getValue();
        } else if(n instanceof Element) {
            result = ((Element)n).getAttributeValue(attrName);
        } else {
            throw new TransportConversionException("Can only extract from" +
                    " element attributes, not " + n);
        }
        if(vp != null)
            vp.check(result);
        return result;

    }

}
