/*
 * Copyright (C) 2008, 2009 Ingo Luetkebohle <iluetkeb@techfak.uni-bielefeld.de>
 * Made available under the terms of the GNU General Public License v3
 */

package de.unibi.agai.xml;

import de.unibi.agai.xml.transport.TransportConversionException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import nu.xom.Attribute;
import nu.xom.Document;
import nu.xom.Element;
import nu.xom.Elements;
import nu.xom.Node;
import nu.xom.ParentNode;

/**
 *
 * @author ingo
 */
public class ElementChildrenSplice implements ValueSplice<Collection<Element>> {
    private final String elementName;
    private final String nsURI;

    public ElementChildrenSplice(String name, String nsURI) {
        if(null == name)
            throw new NullPointerException("Name param must not be null");
        this.elementName = name;
        this.nsURI = nsURI;
    }

    public ParentNode assignTo(ParentNode n, Collection<Element> children) {
        if(n instanceof Document)
            n = ((Document)n).getRootElement();
        Element e = (Element)n;
        if(!elementName.equals(e.getLocalName()) || (nsURI != null &&
                !nsURI.equals(e.getBaseURI()))) {
                e = new Element(elementName, nsURI);
        }
        for(Element child : children)
            e.appendChild(child);

        return e;
    }

    public void assignTo(Attribute a, Collection<Element> o) {
        throw new UnsupportedOperationException("Cannot assign to attributes.");
    }

    public Collection<Element> extract(Node n, ValuePolicy<Collection<Element>> vp) throws TransportConversionException {
        if(n instanceof Document)
            n = ((Document)n).getRootElement();
        final Element e = (Element)n;
        final Elements children = e.getChildElements();
        final List<Element> result = new ArrayList<Element>(children.size());
        for(int i = 0, len = children.size(); i < len; ++i) {
            result.add(children.get(i));
        }
        if(null != vp)
            return vp.check(result);
        else
            return result;
    }

}
