/*
 * Copyright (C) 2008, 2009 Ingo Luetkebohle <iluetkeb@techfak.uni-bielefeld.de>
 * Made available under the terms of the GNU General Public License v3
 */

package de.unibi.agai.xml;

import de.unibi.agai.xml.transport.TransportConversionException;
import nu.xom.Attribute;
import nu.xom.Document;
import nu.xom.Node;
import nu.xom.ParentNode;
import nu.xom.Text;

/**
 * Splices string data as text into elements or as the value of
 * attributes.
 *
 * @author ingo
 */
public class TextSplice implements ValueSplice<String> {
    /** Uses the value of the given node as the value to extract. */
    public String extract(Node n, ValuePolicy<String> vp) throws TransportConversionException {
        if(n == null)
            throw new TransportConversionException("Empty nodeset, cannot extract");
        return vp.check(n.getValue());
    }

    /** Assigns the value to the given attribute. */
    public void assignTo(Attribute n, String o) {
        n.setValue(o);
    }

    /**
     * Add new text child to the given node with the specified text value.
     * If the node is a Document, adds the child to the root element instead.
     * @param n parent element
     * param o value
     */
    public ParentNode assignTo(ParentNode n, String o) {
        if(n instanceof Document)
            n = ((Document)n).getRootElement();
        n.appendChild(new Text(o));
        return n;
    }
}
