/*
 * Copyright (C) 2008, 2009 Ingo Luetkebohle <iluetkeb@techfak.uni-bielefeld.de>
 * Made available under the terms of the GNU General Public License v3
 */

package de.unibi.agai.xml;

import de.unibi.agai.xml.transport.TransportConversionException;
import nu.xom.Attribute;
import nu.xom.Node;
import nu.xom.ParentNode;

/**
 * Interfaces for classes that can extract values from respectively add values
 * to a transport layer.
 * This is usually the first respectively last step in type conversion.
 * 
 * @author ingo
 */
public interface ValueSplice<T> {
    /**
     * Insert the data from o into the given ParentNode.
     */
    ParentNode assignTo(ParentNode n, T o);

    /** 
     * Insert data into attribute. Optional operation.
     * @throws UnsupportedOperationException if data cannot be converted
     *  to an attribute
     */
    void assignTo(Attribute a, T o);

    /**
     * Extract data from the given node and check it against the
     * specified ValuePolicy.
     */
    T extract(Node n, ValuePolicy<T> vp) throws TransportConversionException;
}
