/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.agai.xml.transport;

import java.lang.reflect.Array;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import nu.xom.Elements;
import nu.xom.Node;
import nu.xom.ParentNode;

/**
 *
 * @author iluetkeb
 */
public abstract class AbstractArrayTransportAdapter<T> extends AbstractTransportAdapter<T[]> {
    private static final Logger logger = Logger.getLogger(AbstractArrayTransportAdapter.class.getName());
    private final TransportAdapter<T> ta;

    public AbstractArrayTransportAdapter(TransportAdapter<T> ta, Class<T[]> adaptableClass, String name) {
        super(adaptableClass, name);
        this.ta = ta;
    }

    @Override
    public ParentNode adapt(ParentNode context, T[] o) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public T[] unpack(Node data) throws TransportConversionException {
        List<Node> n = selectListElements(data);
        // BEGIN DEBUG
        if(logger.isLoggable(Level.FINEST)) {
            for(int i = 0, len = n.size(); i < len; ++i)
                logger.log(Level.FINEST, n.get(i).toXML());
        }
        // END DEBUG
        T[] result = (T[]) Array.newInstance(ta.getAdaptableClass(), n.size());
        for(int i = 0, len = n.size(); i < len; ++i) {
            result[i] = ta.unpack(n.get(i));
            logger.finest(result[i].toString());
        }
        return result;
    }

    protected abstract List<Node> selectListElements(Node data) throws TransportConversionException;

    protected List<Node> toList(Elements elems) {
        List<Node> result = new ArrayList<Node>(elems.size());
        for (int i = 0; i < elems.size(); ++i) {
            result.add(elems.get(i));
        }
        return result;
    }
}