/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.agai.xml.transport;

import nu.xom.Attribute;
import nu.xom.Element;
import nu.xom.Node;
import nu.xom.ParentNode;
import nu.xom.Text;

/**
 *
 * @author iluetkeb
 */
public abstract class ChildTransportAdapter<T> extends AbstractTransportAdapter<T> {

    public ChildTransportAdapter(Class<T> clazz, String name) {
        super(clazz, name);
    }

    @Override
    public ParentNode adapt(ParentNode context, T o) {
        Element e = asElement(context);
        // remove all previous text children
        for(int i = 0; i < e.getChildCount(); ) {
            if(e.getChild(i) instanceof Text) {
                e.removeChild(i);
            } else {
                ++i;
            }
        }
        e.insertChild(new Text(toString(o)), 0);

        return e;
    }

    @Override
    public T unpack(Node data) throws TransportConversionException {
        if(data instanceof Attribute)
            return parseFromString(data.getValue());
        Element e = asElement(data);
        StringBuffer sb = new StringBuffer();
        for(int i = 0, len = e.getChildCount(); i < len; ++i) {
            Node c = e.getChild(i);
            if(c instanceof Text)
                sb.append(((Text)c).getValue());
        }
        return parseFromString(sb.toString());
    }

    protected abstract T parseFromString(String value);
    protected abstract String toString(T value);
}
