/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.agai.xml.transport;

import nu.xom.Document;
import nu.xom.Element;
import nu.xom.Node;
import nu.xom.ParentNode;
import nu.xom.Text;

/**
 * Embeds a string as element child. Existing children are removed!
 *
 * On unpacking, uses the string value of the target. In the case of multiple
 * or nested nodes, this may not be what is expected. Check docs for the
 * XPath string(...) function. Note: If the target has been written
 * using this adapter, it will read it fine, so don't worry.
 *
 * @author iluetkeb
 */
public class StringChildTransportAdapter extends AbstractTransportAdapter<String> {

    public StringChildTransportAdapter() {
        super(String.class, "StringChild");
    }

    @Override
    public ParentNode adapt(ParentNode context, String o) {
        if(context instanceof Document)
            context = ((Document)context).getRootElement();
        ((Element)context).removeChildren();
        context.appendChild(new Text(o));
        return context;
    }

    @Override
    public String unpack(Node data) throws TransportConversionException {
        return data.getValue();
    }

}
