/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.agai.xml.transport;

import nu.xom.Document;
import nu.xom.Node;
import nu.xom.ParentNode;
import org.jaxen.XPath;

/**
 * SPI Factory for creating transport objects from arbitrary objects.
 *
 * @author iluetkeb
 */
public interface TransportAdapter<T> {
    /**
     * Wrap parameter in new document.
     * @throws ClassCastException If the object is not of an adaptable type.
     */
    Document adapt(T o);
    
    /**
     * Create Node based on the specified
     * parent transport object.
     * @throws ClassCastException If the object is not of an adaptable type.
     */
    ParentNode adapt(ParentNode context, T o);

    /**
     * Unpack into desired type.
     */
    T unpack(Node data) throws TransportConversionException;
    /**
     * Unpack desired type from given location.
     */
    T unpack(Node data, XPath path) throws TransportConversionException;
    /** 
     * Return the class that can be adapted by this factory.
     */
    Class<T> getAdaptableClass();
    /** 
     * Return a descriptive name for this factory.
     */
    String getName();

    /** 
     * Create a new TransportAdapter instance with the specified context. If
     * this adapter does not need a context, it can return itself.
     */
    TransportAdapter<T> setContext(TransportContext context);

    /**
     * Adapts the given data by navigating to the specified XPath in the
     * XOPData's document and calling assignTo(Node, T).
     * @param context the target Document
     * @param path to where the object should be attached to
     * @param o the object to adapt
     * @throws TransportConversionException if the XPath is not present
     */
    ParentNode adapt(ParentNode context, XPath path, T o) throws TransportConversionException;
}
