/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.agai.xml.transport;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.ServiceLoader;
import java.util.Set;
import java.util.logging.Logger;

/**
 *
 * @author iluetkeb
 */
public class TransportManager {
    private static final Logger logger = Logger.getLogger(TransportManager.class.getName());
    private final Map<String, TransportAdapter<?>> nameMap =
            Collections.synchronizedMap(new HashMap<String, TransportAdapter<?>>());
    private final Map<Class<?>, TransportAdapter<?>> classMap =
            Collections.synchronizedMap(new HashMap<Class<?>, TransportAdapter<?>>());
    
    protected TransportManager() {
        ServiceLoader<TransportAdapter> loader = ServiceLoader.load(TransportAdapter.class);
        for(TransportAdapter<?> af : loader) {
            logger.fine(af.getName());
            addAdapter(af);
        }
    }

    private static TransportManager instance;
    public synchronized final static TransportManager getInstance() {
        if(instance != null)
            return instance;
        instance = new TransportManager();
        return instance;
    }

    public <T> void addAdapter(TransportAdapter<T> af) {
        nameMap.put(af.getName(), af);
        classMap.put(af.getAdaptableClass(), af);
    }

    /** Add the factory to the known set. */
    public static <T> void register(TransportAdapter<T> af) {
        getInstance().addAdapter(af);
        getInstance().addAdapter(af);
    }
    public static <T> void unregister(TransportAdapter<T> af) {
        getInstance().nameMap.remove(af.getName());
        getInstance().classMap.remove(af.getAdaptableClass());
    }

    @SuppressWarnings("unchecked")
    public static <T> TransportAdapter<T> lookup(Class<T> clazz) {
        return (TransportAdapter<T>) getInstance().classMap.get(clazz);
    }
    
    @SuppressWarnings("unchecked")
    public static <T> TransportAdapter<T> lookup(T o) {
        return (TransportAdapter<T>) getInstance().classMap.get(o.getClass());
    }
    public static TransportAdapter<?> lookup(String name) {
        return getInstance().nameMap.get(name);
    }
    public Set<String> names() {
        return getInstance().nameMap.keySet();
    }
    public Set<Class<?>> classes() {
        return getInstance().classMap.keySet();
    }
}
