/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.agai.xml.transport;

import nu.xom.Node;
import nu.xom.ParentNode;
import org.jaxen.JaxenException;
import org.jaxen.XPath;
import org.jaxen.xom.XOMXPath;

/**
 * Transport XPaths in their textual representation.
 *
 * @author iluetkeb
 */
public class XPathTransportAdapter extends AbstractTransportAdapter<XPath> {
    private final StringChildTransportAdapter ta = new StringChildTransportAdapter();

    public XPathTransportAdapter() {
        super(XPath.class, "XPath");
    }

    @Override
    public ParentNode adapt(ParentNode context, XPath o) {
        return ta.adapt(context, o.toString());
    }

    protected XPath createXPath(String xpathText) throws TransportConversionException {
        try {
            return new XOMXPath(xpathText);
        } catch (JaxenException ex) {
            throw new TransportConversionException("Content is not a valid " +
                    "XPath expression", ex);
        }
    }

    @Override
    public XPath unpack(Node data) throws TransportConversionException {
        return createXPath(ta.unpack(data));
    }
}
