/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts;

import java.util.concurrent.ExecutionException;

/**
 * An interface for nodes that need their life-cycle managed.
 * 
 * @author iluetkeb
 */
public interface Activatable {
    public enum State {
        Started, Stopped, Error
    }
    public enum Action {
        Start, Stop
    }

    /**
     * Perform the specified action.
     *
     * @return true when the state was changed as a result of the action,
     *   false otherwise (i.e., the state was already achieved)
     * @throws ExecutionException when state change fails
     */
    boolean performAction(Action action) throws ExecutionException;
    /**
     * Return the current state of the component.
     */
    State getCurrentState();
}
