/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts;

import java.util.Map;

/**
 * Standard event subtype that allows tagging.
 *
 * @author iluetkeb
 */
public interface Event<T> {
    /** Retrieve the data associated with this event. */
    T getData();
    
    /** Retrieve tag by name. */
    Object getTag(String name);
    
    
    /** Retrieve tag by localName and explicit namespace. */
    Object getTag(String localName, String namespace);
    
    
    /** Get all attributes. */
    Map<String, Object> getTags();

    /** Create a new event with the same tags but different data. */
    <K> Event<K> createDerived(K data);

    /** Create a new Event with the given tags added. */
    Event<T> addTags(Pair<String, Object> ... newTags);

    /** Create a new Event with the given tags merged (added, if not present already). */
    Event<T> mergeTags(Map<String, Object> otherTags);

    /** Create a new Event with the named tags removed. The event
     * is otherwise an exact copy. */
    Event<T> removeTags(String ... names);

}
