/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts;

/**
 * Node is the base type of all wrapper classes needed to
 * map processed event data to the user defined (and annotated)
 * handler methods.
 *
 * Note: This interface is typed, with the expectation that the type
 * is either Object or, in the case the graph has special requirements,
 * some common base type (e.g., XcfEvent).
 *
 * @author jschaefe
 *
 */
public interface Node<TIn, TOut> {
    /**
     * Handle input and produce some output.
     * @returns result or null, when no result is produced
     */
	public Event<? extends TOut> handleEvent(Event<? extends TIn> input) throws Exception;
	
}
