/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts;

public class Pair<K, I> {

    public final K first;
    public final I second;

    public Pair(K k, I i) {
        super();
        this.first = k;
        this.second = i;
    }

    @Override
    public boolean equals(Object o) {
        if(!(o instanceof Pair))
            return false;
        return first.equals(((Pair)o).first) && second.equals(((Pair)o).second);
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 53 * hash + (this.first != null ? this.first.hashCode() : 0);
        hash = 53 * hash + (this.second != null ? this.second.hashCode() : 0);
        return hash;
    }

    @Override
    public String toString() {
        return "Pair[k=" + first + ", i=" + second + "]";
    }

    public static <K, I> Pair<K,I> create(K k, I i) {
        return new Pair<K, I>(k, i);
    }
}
