/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.xcf.fts;

import java.util.concurrent.ExecutionException;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 *
 * @author iluetkeb
 */
public abstract class StateSupport implements Activatable {
	private static final Logger logger = 
		Logger.getLogger(StateSupport.class.getName());

	private State state;

	public synchronized boolean performAction(Action action) throws ExecutionException {
		logger.entering(StateSupport.class.getName(), "performAction", action);
		try {
			switch (action) {
				case Start:
					if (state == State.Started) {
						return false;
					}
					start();
                                        state = State.Started;
					return true;
				case Stop:
					if(state == State.Stopped)
						return false;
					stop();
                                        state = State.Stopped;
					return true;
			}
		} catch (Exception ex) {
			final String msg = "Could not " + action;
			logger.logp(Level.SEVERE, "StateSupport",
				"performAction", msg, ex);
			throw new ExecutionException(msg, ex);
		}
		return false;
	}

	public synchronized State getCurrentState() {
		return state;
	}

	/** Implement in subclasses. Will be called when start is needed.*/
	protected abstract void start() throws Exception;

	/** Implement in subclasses. Will be called when stop is needed.*/
	protected abstract void stop() throws Exception;
}
