/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.xcf.fts.engine;

import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.Node;
import net.sf.xcf.fts.Triple;

/**
 * The DepthFirstEngine implements the actual process of transforming Events using an
 * Graph. Based on the nodes and connections stored in the graph, the engine
 * will decide which path an event will take through the graph and will also
 * handle special framework logic, such as registration of an event with a
 * Correlator, if a node wishes to receive an answer to that event.
 * 
 * @author jschaefe
 *
 */
public class DepthFirstEngine extends AbstractEngine implements Runnable {

    public DepthFirstEngine(Graph g) {
        super(g);
    }

    @Override
    @SuppressWarnings("unchecked")
    protected void addWorkItem(Node source, Node next, Event input) {
        // Note: processing sequence here is reverted sequence of calls to connect(),
        // (contrary to the BreadthFirstEngine), which might be a bit misleading
        workQueue.push(new Triple(source, next, input));
    }
}
