package net.sf.xcf.fts.engine;

import java.util.concurrent.atomic.AtomicLong;
import java.util.logging.Logger;

public class EngineThread extends Thread {
    private static final Logger logger =
            Logger.getLogger(EngineThread.class.getName());
    private final Engine engine;

    private static final AtomicLong serial = new AtomicLong();

    /**
     * Creates EngineThread with the specified graph and EngineFactory.
     */
    public EngineThread(Graph g, EngineFactory ef) {
        super("FTS-EngineThread-" + serial.getAndIncrement());
        this.engine = ef.createEngine(g);
        logger.entering(EngineThread.class.getName(), "EngineThread", g);
        logger.fine("Sources " + g.getSourceNodes());
        setDaemon(true);
        logger.exiting(EngineThread.class.getName(), "EngineThread", engine);
    }

    /**
     * Creates EngineThread for this graph using a BreadthFirstEngine.
     *
     * @param g
     */
    public EngineThread(Graph g) {
        this(g, new EngineFactory() {

            public Engine createEngine(Graph g) {
                return new BreadthFirstEngine(g);
            }

        });
    }

    public enum ErrorPolicy {
        Terminate, Log
    }

    public void setErrorPolicy(ErrorPolicy policy) {
        switch(policy) {
            case Terminate:
                engine.setErrorHandler(new TerminatingNodeErrorHandler());
                break;
            case Log:
                engine.setErrorHandler(new LoggingNodeErrorHandler());
                break;
        }
    }

    @Override
    public void run() {
        engine.run();
    }

    @Override
    public void interrupt() {
        logger.entering(EngineThread.class.getName(), "interrupt");
        super.interrupt();
        engine.shutdown();
        logger.exiting(EngineThread.class.getName(), "interrupt");
    }
}
