/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.engine;

import net.sf.xcf.fts.Node;
import net.sf.xcf.fts.Event;

/**
 * Event generated when Node.handleEvent causes an error.
 *
 * @author iluetkeb
 */
public class NodeErrorEvent<T> {
    private final Node<?,? extends T> sourceNode;
    private final Node<? super T, ?> workNode;
    private final Event<? extends T> data;
    private final Exception ex;

    public NodeErrorEvent(Node<?,? extends T> sourceNode,
            Node<? super T, ?> workNode,
            Event<? extends T> data, Exception ex) {
        this.sourceNode = sourceNode;
        this.workNode = workNode;
        this.data = data;
        this.ex = ex;
    }

    /** Returns the input element that caused the workNode to throw an error. */
    public Event<? extends T> getData() {
        return data;
    }

    /** Returns the exception thrown. */
    public Exception getError() {
        return ex;
    }

    /** Returns the node that produced the input data. May be null. */
    public Node<?,? extends T> getSourceNode() {
        return sourceNode;
    }

    /** Returns the node that caused the exception. */
    public Node<? super T,?> getWorkNode() {
        return workNode;
    }

    @Override
    public String toString() {
        return "NodeErrorEvent[workNode=" + workNode +
        		", previousNode=" + sourceNode + 
                ", input data=" + (data != null ? data.getData() : "") + 
                ", error=" + ex + "]";
    }
 }
