package net.sf.xcf.fts.engine;

import java.util.concurrent.Callable;

import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.Node;
import net.sf.xcf.fts.Triple;
import net.sf.xcf.fts.engine.EngineEventListener.EngineEvent;
import net.sf.xcf.fts.engine.EngineEventListener.EngineEventType;

public class SourceCompletionCallable<T> implements
        Callable<Triple<Node<?,T>, Event<? extends T>, Exception>> {

    private final Engine engine;
    private final Node<?,T> source;

    public SourceCompletionCallable(Engine engine, Node<?,T> s) {
        this.engine = engine;
        this.source = s;
    }

    @Override
    public Triple<Node<?,T>, Event<? extends T>, Exception> call()
            throws Exception {
        try {
            // Until Source interface is changed, use handleEvent
            // instead of Source.next, to facilitate Sources
            // which produce their own Events.
            
            engine.notifyEngineListeners(new EngineEvent(EngineEventType.HANDLE_EVENT_CALLED, source, null, null));
            Event<? extends T> evt = this.source.handleEvent(null);
            engine.notifyEngineListeners(new EngineEvent(EngineEventType.HANDLE_EVENT_FINISHED, source, null, null));
            
            return new Triple<Node<?,T>, Event<? extends T>, Exception>(this.source, evt, null);
        } catch (Exception e) {
            return new Triple<Node<?,T>, Event<? extends T>, Exception>(this.source, null, e);
        }
    }
}
