/**
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2009 David Klotz <mail -at- planetraven -dot- de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.xcf.fts.engine.jmx;

import java.io.Serializable;

import net.sf.xcf.fts.engine.EngineEventListener.EngineEvent;
import net.sf.xcf.fts.engine.EngineEventListener.EngineEventType;
import net.sf.xcf.fts.engine.EngineEventListener.TimedNodeEvent;

/**
 * A wrapper that encapsulates all the relevant information of an
 * {@link EngineEventListener.EngineEvent} for sending via JMX.
 * 
 * @author dklotz
 */
public class EngineEventWrapper implements Serializable, TimedNodeEvent<NodeWrapper> {

    /** To enable serialization. */
    private static final long serialVersionUID = 3586016853996775842L;

    private final EngineEventType type;
    private final long creationTime;
    private final NodeWrapper source;
    private final NodeWrapper destination;
    private final int queueSize;

    public EngineEventWrapper(EngineEvent event) {
        this.type = event.type;
        this.creationTime = event.creationTime;
        this.source = (event.source == null) ? null : new NodeWrapper(event.source);
        this.destination = (event.destination == null) ? null : new NodeWrapper(event.destination);
        this.queueSize = event.queueSize;
    }

    public EngineEventType getType() {
        return type;
    }

    public NodeWrapper getSource() {
        return source;
    }

    public NodeWrapper getDestination() {
        return destination;
    }
    
    public long getCreationTime() {
        return creationTime;
    }

    public int getQueueSize() {
        return queueSize;
    }
    
    @Override
    public String toString() {
        return "[EngineEvent: type=" + type + ", source=" + source
                + ", destination=" + destination + "]";
    }
}