/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.engine.jmx;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.logging.Logger;
import net.sf.xcf.fts.Node;
import net.sf.xcf.fts.engine.EngineEventListener;

/**
 * Compute a few simple statistics one nodes.
 *
 * @author iluetkeb
 */
public class NodeStatisticsListener implements EngineEventListener {
    private static final Logger logger = 
            Logger.getLogger(NodeStatisticsListener.class.getName());

    public enum Variables {
        CallCount, ProductionCount
    }

    private Map<Node<?,?>, AtomicInteger> callCount = 
            new HashMap<Node<?,?>, AtomicInteger>();
    private Map<Node<?,?>, AtomicInteger> productionCount =
            new HashMap<Node<?,?>, AtomicInteger>();

    protected static int increment(Map<Node<?,?>, AtomicInteger> countMap,
            Node<?,?> key) {
        if(key == null)
            logger.warning("Got null key for map " + countMap.hashCode());
        if(!countMap.containsKey(key)) {
            countMap.put(key, new AtomicInteger(0));
        }
        return countMap.get(key).incrementAndGet();
    }

    public synchronized void handleEngineEvent(EngineEvent event) {
        increment(callCount, event.destination);
        increment(productionCount, event.source);
    }

    @Override
    public String toString() {
        return "call count: " + callCount + "\n" +
                "data production: " + productionCount + "\n";
    }

    /**
     * Retrieve the value of the given statics variable for the specified
     * node.
     *
     * @return the count or -1, if the node has not been counted.
     */
    public int getStatistic(Variables var, Node<?,?> key) {
        AtomicInteger value = null;
        switch(var) {
            case CallCount:
                value = callCount.get(key);
                break;
            case ProductionCount:
                value = productionCount.get(key);
                break;
        }
        if(value == null)
            return -1;
        else
            return value.get();
    }

}
