/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package net.sf.xcf.fts.export;

import java.util.Collection;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;

import net.sf.xcf.fts.engine.Graph;
import net.sf.xcf.fts.engine.jmx.GraphWrapper;
import net.sf.xcf.fts.engine.jmx.NodeWrapper;

/**
 * Take a graph and produce "dot" output. The object will keep
 * track of graph nodes already seen and won't add them again (this
 * is also a protection against endless loops for graphs with circles).
 * Multiple graphs may be added and they will all appear in the output.
 *
 * @author iluetkeb
 * @author dklotz
 */
public class DotGraphExport {
    protected Set<NodeWrapper> nodesSeen = new HashSet<NodeWrapper>();
    private final StringBuilder dotDoc = new StringBuilder();
    
    protected void appendDescendants(StringBuilder sb, GraphWrapper g, NodeWrapper n) {
        if(nodesSeen.contains(n))
            return;
        nodesSeen.add(n);
        
        Map<String, String> attrs = new HashMap<String, String>();

        if(n.isTransformNode()) {
            attrs.put("shape", "box");
        }
        attrs.put("label", "\"" + formatNodeLabel(n) + "\"");

        sb.append(formatAttrs(n, attrs));

        Iterator<NodeWrapper> iter = g.getEmergents(n).iterator();
        while(iter.hasNext()) {
            NodeWrapper next = iter.next();
            sb.append(n.getId()).append(" -> ");
            sb.append(next.getId());
            sb.append(";\n");
            appendDescendants(sb, g, next);
        }
    }

    protected String formatAttrs(NodeWrapper n, Map<String, String> attrs) {
        if(attrs.size() == 0)
            return "";
        StringBuilder sb = new StringBuilder();
        sb.append(n.getId()).append(" [");

        String[] parts = new String[attrs.size()];
        int index = 0;
        for(Map.Entry<String, String> e : attrs.entrySet()) {
            parts[index++] = e.getKey() + '=' + e.getValue();
        }
        for(int i = 0; i < parts.length; ++i) {
            sb.append(parts[i]);
            if(i < (parts.length -1))
                sb.append(",");
        }


        return sb.append("];\n").toString();
    }

    protected String formatNodeLabel(NodeWrapper n) {
        return n.getOriginalToString().replace("\"", "\\\"");
    }

    public void addGraph(String name, Graph g) {
        addGraph(name, new GraphWrapper(g));
    }
    
    public void addGraph(String name, GraphWrapper g) {
        nodesSeen.clear();
        dotDoc.append("\ndigraph ").append(name).append(" {\n");
        // traverse all edges and add them
        Collection<NodeWrapper> sources = g.getSourceNodes();
        for(NodeWrapper n : sources) {
            appendDescendants(dotDoc, g, n);
        }
        dotDoc.append("}\n");
    }

    public String getDotString() {
        return dotDoc.toString();
    }
}
