/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes;

import net.sf.xcf.fts.Node;


/**
 * An abstract base class for {@link Node}s that provides a name for a node.
 * 
 * @author iluetkeb
 */
public abstract class AbstractNode<TIn, TOut> implements Node<TIn, TOut> {

    protected final String name;

    public AbstractNode(){
        String simpleName = getClass().getSimpleName();
        // anon classes have an empty simple name, so use their full name instead
        if(simpleName == null || simpleName.length() == 0)
            simpleName = getClass().getName();
        this.name = simpleName;
    }

    public AbstractNode(String name) {
        this.name = name;
    }
    
    @Override
    public String toString() {
        return "Node[name=" + name + "]";
    }
    
    /**
     * Returns the name of this node.
     *
     * @return A string.
     */
    public String getName() {
        return name;
    }
}
