/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes;

import java.util.concurrent.ExecutionException;
import net.sf.xcf.fts.Activatable;
import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.Node;
import net.sf.xcf.fts.StateSupport;
import net.sf.xcf.fts.annotations.NodeName;

/**
 * Combine functionality of several nodes into one.
 *
 * @author iluetkeb
 */
@NodeName("Compound")
public class CompoundNode implements Node, Activatable {
    private final Node[] nodes;

    @Deprecated
    public CompoundNode(Node ... nodes) {
        this.nodes = nodes;
    }

    public <T> CompoundNode(Node<?, ? extends T> n1, Node<? super T,?> n2) {
        nodes = new Node[]{ n1, n2 };
    }
    public <T, T2> CompoundNode(Node<?, ? extends T> n1,
            Node<? super T,? extends T2> n2, Node<? super T2,?> n3) {
        nodes = new Node[]{ n1, n2, n3 };
    }
    public <T, T2, T3> CompoundNode(Node<?, ? extends T> n1,
            Node<? super T,? extends T2> n2, Node<? super T2,? extends T3> n3,
            Node<? super T3,?> n4) {
        nodes = new Node[]{ n1, n2, n3, n4 };
    }

    public Event handleEvent(Event input) throws Exception {
        for(Node n : nodes) {
            input = n.handleEvent(input);
            if(input == null)
                break;
        }
        return input;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        for(Node n : nodes)
            sb.append(n.toString());
        return sb.toString();
    }

    private final StateSupport stateSupport = new StateSupport() {

        @Override
        protected void start() throws Exception {
            for(Node n : nodes) {
                if(n instanceof Activatable) {
                    ((Activatable)n).performAction(Action.Start);
                }
            }
        }

        @Override
        protected void stop() throws Exception {
            for(Node n : nodes) {
                if(n instanceof Activatable) {
                    ((Activatable)n).performAction(Action.Stop);
                }
            }
        }

    };

    public boolean performAction(Action action) throws ExecutionException {
        return stateSupport.performAction(action);
    }

    public State getCurrentState() {
        return stateSupport.getCurrentState();
    }
}
