/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes;

import java.util.Arrays;
import java.util.List;

import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.Node;

/**
 * Branching node that selects only until a node returns a non-zero result.
 *
 * @author iluetkeb
 */
@NodeName("SelectFirst")
public class SelectFirstNode extends AbstractNode<Object, Object> {
    private final List<Node> candidates;
    private final boolean mustSelect;
    
    public SelectFirstNode(boolean mustSelect, Node ... candidates) {
        super("SelectFirst");
        this.mustSelect = mustSelect;
        this.candidates = Arrays.asList(candidates);
    }
    public SelectFirstNode(Node ... candidates) {
        this(false, candidates);
    }

    /**
     * @throws IllegalArgumentException if mustSelect is true and none
     *   of the specified output nodes has produced a result.
     */
    public Event<? extends Object> handleEvent(Event<? extends Object> input) throws Exception {
        Event result = null;
        for(Node n : candidates) {
            result = n.handleEvent(input);
            if(result != null)
                break;
        }
        if(result == null && mustSelect)
            throw new IllegalArgumentException("No output node found");
        return result;
    }
}
