/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package net.sf.xcf.fts.nodes.correlation;

import java.util.concurrent.ExecutionException;
import java.util.concurrent.Future;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;
import java.util.logging.Level;
import java.util.logging.Logger;
import net.sf.xcf.fts.Event;

/**
 * Adapter for correlators that feeds into a future when correlation
 * is successfull.
 * 
 * @author iluetkeb
 */
public class CorrelatableFuture<V> implements Correlatable<V>, Future<V> {
    private static final Logger logger = Logger.getLogger(CorrelatableFuture.class.getName());
    /** Wrapped correlatable. */
    private final Correlatable<V> correlatable;
    /** The data item that is the result of the computation. */
    protected V resultData;
    /** Whether the operation is complete. */
    protected boolean complete = false;

    /** Create CF by wrapping the given correlatable. */
    public CorrelatableFuture(Correlatable<V> correlatable) {
        this.correlatable = correlatable;
    }

    @Override
    public boolean cancel(boolean mayInterruptIfRunning) {
        // communication tasks are half-way through execution always
        // the send part is done already, so they cannot be cancelled
        return false;
    }

    /** Resets completion state of this object. Be sure to only use this
     * when there is no operation pending! */
    public final void reset() {
        complete = false;
        resultData = null;
    }

    @Override
    public synchronized V get() throws InterruptedException, ExecutionException {
        try {
            return get(0L, TimeUnit.DAYS);
        } catch (TimeoutException ex) {
            Logger.getLogger(CorrelatableFuture.class.getName()).log(Level.SEVERE, null, ex);
            throw new ExecutionException(ex);
        }
    }

    @Override
    public synchronized V get(long timeout, TimeUnit unit) throws InterruptedException, ExecutionException, TimeoutException {
        if (!isDone()) {
            wait(timeout);
        }
        if (!complete) {
            throw new TimeoutException();
        }
        return resultData;
    }

    @Override
    public final boolean isCancelled() {
        return false;
    }

    @Override
    public final boolean isDone() {
        return complete;
    }

    public boolean correlate(Event<? extends V> evt) {
        logger.entering(CorrelatableFuture.class.getName(), "correlate", evt);
        if(correlatable.correlate(evt)) {
            this.resultData = evt.getData();
            complete = true;
            notifyAll();
            return true;
        } else {
            return false;
        }
    }
}
