/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.correlation;

import java.util.HashSet;
import java.util.Set;
import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.Node;

/**
 * Transformation node that accepts both Correlatables and other input.
 * Correlatable will be stored. Other input will be matched to all currently
 * stored correlatables and if successful, the correlatalable is removed
 * internally and returned.
 *
 * @author iluetkeb
 */
@NodeName("Correlator")
public class CorrelatorNode implements Node {
    private final Set<Event<Correlatable>> outstanding = new HashSet();

    public Event handleEvent(Event input) throws Exception {
        if(input.getData() instanceof Correlatable) {
            outstanding.add(input);
        } else {
            for(Event<Correlatable> evt : outstanding) {
                if(evt.getData().correlate(input)) {
                    outstanding.remove(evt);
                    return evt;
                }
            }
        }
        return null;
    }


}
