/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.correlation;

import java.util.HashSet;
import java.util.Set;
import java.util.UUID;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.Future;
import net.sf.xcf.fts.DefaultEvent;
import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.Pair;
import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.Node;

/**
 *
 * @author iluetkeb
 */
@NodeName("Correlator")
public class WrapAroundCorrelatorNode implements Node {
    private final BlockingQueue<Event> queue;
    private final Set<Correlatable> outstanding = new HashSet();

    public static final String CORRELATION_ID = "ID";

    public WrapAroundCorrelatorNode(BlockingQueue queue) {
        this.queue = queue;
    }

    /** */
    public Future push(Object o) throws InterruptedException {
        UUID value = UUID.randomUUID();
        queue.put(new DefaultEvent(o).addTags(new Pair(CORRELATION_ID, value)));
        CorrelatableFuture cf = new CorrelatableFuture(new TagCorrelator(CORRELATION_ID, value));
        outstanding.add(cf);
        return cf;
    }

    public Event handleEvent(Event input) throws Exception {
        for(Correlatable corr : outstanding) {
            if(corr.correlate(input)) {
                outstanding.remove(corr);
            }
        }
        return null;
    }

    @Override
    public String toString() {
        return "WrapAroundCorrelator";
    }
}
