/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.filter;

import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.annotations.ReceiveLast;

/**
 * Filter that simply delays a specified number of milliseconds.
 * 
 * <strong>WARNING if Breadth or DepthFirstEngines are used, this will block
 * everything!</strong> With the QueueingEngine, it will only block the
 * specific path.
 *
 * @author iluetkeb
 */
@NodeName("Delay")
@ReceiveLast
public class DelayFilter extends AbstractFilter {
    private final long delay;

    public DelayFilter(Long delay) {
        this.delay = delay;
    }
    
    @Override
    public boolean isMatch(Event e) throws Exception {
        Thread.sleep(delay);
        return true;
    }

}
