/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.xcf.fts.nodes.filter;

import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.annotations.NodeName;

/**
 * Verifies that the "filter.boolean" key is present and has a true value. 
 *
 * @author iluetkeb
 */
@NodeName("MapBooleanFilter")
public class MapBooleanFilter extends AbstractFilter<Map<String, Object>> {

    public static final String KEY_BOOLEAN = "filter.boolean";
    
    //private final String mapKey;
    private final Set<String> mapKeys = new HashSet<String>();

    public MapBooleanFilter() {
        this(KEY_BOOLEAN);
    }

    public MapBooleanFilter(String mapKeysString) {
        for (String mapKey : mapKeysString.trim().split(",")) {
            mapKey = mapKey.trim();
            
            if (!mapKey.isEmpty()) {
                mapKeys.add(mapKey);
            }
        }
    }

    public boolean isMatch(Event<? extends Map<String, Object>> e) throws Exception {
        boolean result = true;

        for (String mapKey : mapKeys) {
            final Boolean b = (Boolean) e.getData().get(mapKey);
            result &= ((b != null) && b);
        }

        return result;
    }

    @Override
    public String toString() {
        return "Map-" + mapKeys + " == true";
    }
}
