/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.filter;

import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.annotations.NodeName;

/**
 * Filter that passes every nth millisecond.
 * 
 * @author iluetkeb
 */
@NodeName("PeriodicFilter")
public class PeriodicFilter extends AbstractFilter {
    private final int period;
    private long lastFired = 0;
    
    public PeriodicFilter(Integer period) {
        this.period = period;
    }

    @Override
    public boolean isMatch(Event e) throws Exception {
        if((System.currentTimeMillis() - lastFired) > period) {
            lastFired = System.currentTimeMillis();
            return true;
        }
        return false;
    }

}
