/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.filter;

import java.util.regex.Pattern;
import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.annotations.NodeName;

/**
 * Passes if String data matches the Java regular expression, or, optionally,
 * if it contains a match.
 * 
 * @author iluetkeb
 */
@NodeName("RegexStatic")
public class RegexStaticFilter extends AbstractFilter<String> {
    private final Pattern regex;
    private final boolean find;
    
    public RegexStaticFilter(String regex, Boolean find) {
        if(regex == null)
            throw new NullPointerException("Regular expression must not be null");
        this.regex = Pattern.compile(regex);
        this.find = find;
    }
    /** Create a regex filter which uses full matching (i.e. find is false). */
    public RegexStaticFilter(String regex) {
        this(regex, false);
    }

    public boolean isMatch(Event<? extends String> e) throws Exception {
        if(find)
            return regex.matcher(e.getData()).find();
        else
            return regex.matcher(e.getData()).matches();
    }

}
