/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.filter;

import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.annotations.Filter;
import net.sf.xcf.fts.annotations.NodeName;

/**
 * Check that the specified tag has the specified value.
 *
 * @author iluetkeb
 */
@NodeName("TagFilter")
@Filter
public class TagFilter<T> extends AbstractFilter<T> {
    private final String tagName;
    private final Object tagValue;

    public TagFilter(String tagName, Object tagValue) {
        if(tagName == null || tagValue == null) {
            throw new NullPointerException("Neither name (" + tagName + ") nor" +
                    " value (" + tagValue + ") may be null.");
        }
        this.tagName = tagName;
        this.tagValue = tagValue;
    }

    @Override
    public boolean isMatch(Event<? extends T> e) {
        return tagValue.equals(e.getTag(tagName));
    }

    @Override
    public String toString() {
        return "[" + tagName + " == " + tagValue + "]";
    }

}
