/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.filter;

import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.annotations.Filter;
import net.sf.xcf.fts.annotations.NodeName;

/**
 * Checks that the incoming type is of the specified class.
 *
 * @author iluetkeb
 */
@NodeName("TypeFilter")
@Filter
public class TypeFilter extends AbstractFilter {
    private final Class targetType;

    public TypeFilter(Class targetType) {
        this.targetType = targetType;
    }
    public TypeFilter(String name) throws ClassNotFoundException {
        this.targetType = Class.forName(name);
    }

    @Override
    public boolean isMatch(Event e) {
        return e.getData() != null && targetType.isAssignableFrom(e.getData().getClass());
    }

    @Override
    public String toString() {
        return "isAssignableTo-" + targetType.getSimpleName();
    }
}
