/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.xcf.fts.nodes.filter;

import java.util.HashMap;
import java.util.Map;

import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.annotations.Filter;
import net.sf.xcf.fts.annotations.NodeName;
import nu.xom.Document;

import org.jaxen.JaxenException;
import org.jaxen.xom.XOMXPath;

/**
 * Check if a given XPath is present in the input Document.
 *
 * @author jschaefe
 */
@NodeName("XPathFilter")
@Filter
public class XPathMatcherNode extends AbstractFilter<Document> {

    /** The expression to check for. */
    protected XOMXPath xpathExpr;

    public XPathMatcherNode(String xpath) throws JaxenException {
        this(xpath, new HashMap<String, String>());
    }

    public XPathMatcherNode(String xpath, String nsPrefix, String nsUri) throws JaxenException {
        this(xpath, XPathMatcherNode.buildNamespaceMap(nsPrefix, nsUri));
    }

    public XPathMatcherNode(String xpath, Map<String, String> namespaces) throws JaxenException {
        this.xpathExpr = new XOMXPath(xpath);
        for (String prefix : namespaces.keySet()) {
            this.xpathExpr.addNamespace(prefix, namespaces.get(prefix));
        }
    }

    protected static Map<String, String> buildNamespaceMap(String pfx, String uri) {
        Map<String, String> map = new HashMap<String, String>(1);
        map.put(pfx, uri);
        return map;
    }

    @Override
    public boolean isMatch(Event<? extends Document> e) throws JaxenException {
        return xpathExpr.booleanValueOf(e.getData());
    }

    /** Returns the XPath's string representation. */
    @Override
    public String toString() {
        return xpathExpr.toString();
    }
}
