/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.fusion;

import java.util.Map;
import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.annotations.Fuse;
import net.sf.xcf.fts.annotations.Transform;

/**
 * A tagged fusion node that makes sure a certain number of elements are in
 * the map. This is a cheap form of making sure all the elements are present.
 * By default, it also clears the map after producing it.
 *
 * @author iluetkeb
 */
@Transform @Fuse
public class CountingTaggedFusionNode extends TaggedFusionNode {
    private final int count;
    private final boolean useOnceOnly;

    /** Create a node checking for the given count and clearing the map
     * after producing it, so the next run starts afresh.
     */
    public CountingTaggedFusionNode(int count) {
        this.count = count;
        useOnceOnly = true;
    }
    /** Create a node checking for the given count and using the
     * specified re-use policy.
     */
    public CountingTaggedFusionNode(int count, boolean useOnceOnly) {
        this.count = count;
        this.useOnceOnly = useOnceOnly;
    }

    @Override
    public Event<? extends Map<String, Object>> handleEvent(Event<? extends Object> input) {
        final Event<? extends Map<String, Object>> result = super.handleEvent(input);
        if(result.getData().size() < count) {
            return null;
        }
        if(useOnceOnly)
            this.fusedData.clear();
        return result;
    }

    @Override
    public String toString() {
        return "CountingTaggedFusionNode[count=" + count + ", useOnceOnly=" +
                useOnceOnly + "]";
    }
}
