/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.fusion;

import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.Pair;
import net.sf.xcf.fts.annotations.Transform;
import net.sf.xcf.fts.Node;

/**
 * Attaches a string tag to all incoming data to provide, e.g.
 * source identification for name-based fusion.
 *
 * @author iluetkeb
 */
@Transform
public class FusionSourceTagNode<T> implements Node<T, T> {
    private final String tag;

    public FusionSourceTagNode(String tag) {
        this.tag = tag;
    }

    @Override
    public String toString() {
        return "FusionSourceTagNode[tag=" + tag + "]";
    }

    public Event<? extends T> handleEvent(Event<? extends T> input) throws Exception {
        return input.addTags(new Pair(TaggedFusionNode.MAP_FUSE_NAME, tag));
    }
}
