/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.fusion;

import java.util.Set;
import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.nodes.filter.AbstractFilter;

import static net.sf.xcf.fts.nodes.fusion.TaggedFusionNode.*;

/**
 * For association ids that are numbers, checks that the absolute distance 
 * between all pairs is less than a maximum number. 
 *
 * @author iluetkeb
 */
@NodeName("NumberDistanceAssociationFilter")
public class NumberDistanceAssociationFilter extends AbstractFilter {
    private final int maxDistance;
    
    public NumberDistanceAssociationFilter(Integer maxDistance) {
        this.maxDistance = maxDistance;
    }


    @Override
    public boolean isMatch(Event e) throws Exception {
        final Set<Object> associationIDs = (Set<Object>) e.getTag(MAP_FUSE_ASSOCIATION_ID);
        if(associationIDs == null)
            return false;
        // parse ids as longs. if that is not possible, assocation failed
        final long[] numbers = new long[associationIDs.size()];
        int idx = 0;
        for(Object o : associationIDs) {
            if(o instanceof Number)
                numbers[idx++] = ((Number)o).longValue();
            else
                return false;
        }

        // check that the distance is acceptable for all pairings
        for(int i = 0; i < numbers.length; ++i) {
            for(int j = i+1; j < numbers.length; ++j) {
                if(Math.abs(numbers[i] - numbers[j]) > maxDistance)
                    return false;
            }
        }

        return true;
    }

}
