/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.fusion;

import java.util.UUID;
import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.Pair;
import net.sf.xcf.fts.annotations.Fuse;
import net.sf.xcf.fts.annotations.NodeName;

/**
 * Pair fusion that clears its data after delivering it.
 *
 * @author iluetkeb
 */
@NodeName("OnceOnlyPair") @Fuse
public class OnceOnlyPairFusion<T1,T2> extends PairFusion<T1,T2> {
    public OnceOnlyPairFusion(UUID uuid1, UUID uuid2) {
        super(uuid1, uuid2);
    }
    public OnceOnlyPairFusion(String one, String two) {
        super(one, two);
    }
    @Override
    public Event<? extends Pair<T1, T2>> handleEvent(Event<? extends Object> input) throws Exception {
        Event<? extends Pair<T1, T2>> result = super.handleEvent(input);
        if(result != null) {
            this.first = null;
            this.second = null;
        }
        return result;
    }

    public String toString() {
        return "onceOnly(" + super.toString() + ")";
    }
}
