/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.fusion;

import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.annotations.Fuse;

/**
 * A fusion node that requires specific names to be present.
 * 
 * @author iluetkeb
 */
@Fuse
public class RequiredNamesTaggedFusionNode extends TaggedFusionNode {
    private final Set<String> requiredNames;
    private final boolean useOnceOnly;

    /** Create a node checking for the given count and clearing the map
     * after producing it, so the next run starts afresh.
     */
    public RequiredNamesTaggedFusionNode(List<String> requiredNames, Boolean useOnceOnly) {
        this.requiredNames = new HashSet<String>(requiredNames);
        this.useOnceOnly = useOnceOnly;
    }
    public RequiredNamesTaggedFusionNode(List<String> requiredNames) {
        this(requiredNames, true);
    }

    @Override
    public Event<? extends Map<String, Object>> handleEvent(Event<? extends Object> input) {
        final Event<? extends Map<String, Object>> result = super.handleEvent(input);

        // check all required names
        if(!result.getData().keySet().containsAll(requiredNames))
            return null;

        if(useOnceOnly)
            this.fusedData.clear();
        return result;
    }

    @Override
    public String toString() {
        return "RequiredNamesTaggedFusionNode[names=" + requiredNames +
                ", useOnceOnly=" + useOnceOnly + "]";
    }

}
