/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.sink;

import java.util.Collection;

import net.sf.xcf.fts.annotations.NodeName;

/**
 * Simple sink that collects all its inputs.
 *
 * @author ingo
 */
@NodeName("CollectionSink")
public class CollectionSink<T> extends SinkAdapter<T> {
    private final Collection<T> data;
    
    public CollectionSink(Collection<T> data) {
        super("CollectionSink");
        this.data = data;
    }

    @Override
    protected void pushItem(T e) {
        data.add(e);
    }

    /**
     * Returns the collection used. This is the real object, not a copy, and
     * any manipulation will affect the internal data.
     */
    public Collection<T> getCollection() {
        return data;
    }
}
