/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.source;

import java.util.logging.Logger;
import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.EventFactory;
import net.sf.xcf.fts.Source;
import net.sf.xcf.fts.TaggingEventFactory;
import net.sf.xcf.fts.nodes.AbstractNode;

/**
 * Base class for sources that generate their own events. For FTS internal use
 * only! Non fts-developers, please use SourceAdapter instead.
 *
 * @author iluetkeb
 * @see net.sf.xcf.fts.nodes.source.SourceAdapter
 */
public abstract class AbstractSource<T> extends AbstractNode<Void, T> implements Source<T> {
    private static final Logger logger =
            Logger.getLogger(AbstractSource.class.getName());
    private static final EventFactory defaultFactory = new TaggingEventFactory();
    private final EventFactory ef;

    public AbstractSource(String name, EventFactory factory) {
        super(name);
        ef = factory;
    }

    public AbstractSource(String name) {
        this(name, defaultFactory);
    }

    public AbstractSource(EventFactory factory){
        super();
        ef = factory;
    }

    public AbstractSource(){
        this(defaultFactory);
    }

    /** Utility method to create new Events. */
    protected Event<? extends T> createNewEvent(T data) {
        return ef.createNewEvent(data);
    }

    /**
     * Returns a freshly created event with a data element supplied by next().
     * 
     * @param input Must be null
     * @return The new event
     * @throws Exception whatever next() may throw.
     */
    @Override
    public final Event<? extends T> handleEvent(Event<? extends Void> input) throws Exception {
        return next();
    }

    /**
     * Creates a new Event using the EventFactory and containing data
     * from nextItem().
     *
     * @return A new event containing nextItem datra
     * @throws Exception
     */
    public abstract Event<? extends T> next() throws Exception;

}
