/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.source;

import java.util.concurrent.ArrayBlockingQueue;
import java.util.concurrent.BlockingQueue;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Base class for adapting listeners into a source.
 * 
 * @author iluetkeb
 */
public class EventListenerSourceAdapter<T> extends SourceAdapter<T> {
    private final Logger logger =
            Logger.getLogger(EventListenerSourceAdapter.class.getName());

    protected final BlockingQueue<T> eventQueue = new ArrayBlockingQueue<T>(50);
    
    public EventListenerSourceAdapter(String name) {
        super(name);
    }

    protected int size() {
        return eventQueue.size();
    }

    @Override
    public T nextItem() throws Exception {
        return eventQueue.take();
    }

    /** 
     * Convenience method for sub-class to drop off their input.
     * Use this method if you want to block but ignore the InterruptedException
     * that may be thrown when waiting fails. Otherwise, just add to the
     * queue directly!
     */
    protected void add(T evt) {
        try {
            eventQueue.put(evt);
        } catch (InterruptedException ex) {
            logger.logp(Level.SEVERE, getClass().getName(), "stateChanged",
                    "Queue put failed", ex);
        }
    }
}
