/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.xcf.fts.nodes.source;

import net.sf.xcf.fts.annotations.NodeName;

/**
 *
 * @author iluetkeb
 */
@NodeName("FibonacciSource")
public class FibonacciSource extends SourceAdapter<Integer> {

    private int prev1 = 1, prev0 = 0;
    protected long lastTimestamp = System.currentTimeMillis();
    protected int interval;

    public FibonacciSource() {
        this(0);
    }

    public FibonacciSource(int interval) {
        super("FibonacciSource");
        this.interval = interval;
    }

    public Integer nextItem() throws Exception {
        final long diff = System.currentTimeMillis() - lastTimestamp;
        if (diff < interval) {
            Thread.sleep(interval - diff);
        }

        final int num = prev1 + prev0;
        prev0 = prev1;
        prev1 = num;
        lastTimestamp = System.currentTimeMillis();
        return new Integer(num);
    }
}
