/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.xcf.fts.nodes.source;

import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.EventFactory;

/**
 * Abstract node implementation that conforms to the Source interface.
 * Use this as a base for new Sources, by implementing the "nextItem" method.
 *
 */
public abstract class SourceAdapter<T> extends AbstractSource<T> {

    /**
     * Create SourceAdapter that creates event using the default factory
     * and the simple classname as a name.
     */
    public SourceAdapter(){
        super();
    }

    /**
     * Create SourceAdapter that creates event using the given EventFactory.
     * The source's name will be it's simple classname.
     * @param factory Factory to use for creating events.
     */
    public SourceAdapter(EventFactory factory){
        super(factory);
    }

    /**
     * Create SourceAdapter that creates event using the default factory.
     *
     * @param name Name of this node.
     */
    public SourceAdapter(String name) {
        super(name);
    }
    /** 
     * Create SourceAdapter that creates event using the given EventFactory.
     * 
     * @param name Name of this node
     * @param factory Factory to use for creating events.
     */
    public SourceAdapter(String name, EventFactory factory) {
        super(name, factory);
    }

    @Override
    public String toString() {
        return "SourceAdapter[name=" + name + "]";
    }

    /**
     * Creates a new Event using the EventFactory and containing data
     * from nextItem().
     *
     * @return A new event containing nextItem datra
     * @throws Exception
     */
    public final Event<? extends T> next() throws Exception {
        return createNewEvent(nextItem());
    }

    /**
     * Implement this in sub-classes to create the next event data object.
     */
    protected abstract T nextItem() throws Exception;
}
