/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.xcf.fts.nodes.source;

import net.sf.xcf.fts.annotations.NodeName;
import nu.xom.Document;
import nu.xom.Element;
import nu.xom.Text;

/**
 *
 * @author jschaefe
 */
@NodeName("XMLFibonacciSource")
public class XOMFibonacciSource extends SourceAdapter<Document> {

    private int n0, n1;
    private final Text value;
    private final Text predecessor;
    private final Text prePredecessor;
    private final Document doc;

    public XOMFibonacciSource() {
        super("XOM fibonacci");
        value = new Text("");
        predecessor = new Text("");
        prePredecessor = new Text("");
        Element fib = new Element("fibonacci");
        Element valueElm = new Element("value");
        valueElm.appendChild(value);
        fib.appendChild(valueElm);
        Element predecessorElm = new Element("predecessor");
        predecessorElm.appendChild(predecessor);
        fib.appendChild(predecessorElm);
        Element prePredecessorElm = new Element("prepredecessor");
        prePredecessorElm.appendChild(prePredecessor);
        fib.appendChild(prePredecessorElm);
        doc = new Document(fib);
        n0 = 0;
        n1 = 1;
    }

    public boolean isBlocked() {
        return false;
    }

    @Override
    public Document nextItem() throws Exception {
        prePredecessor.setValue("" + n0);
        predecessor.setValue("" + n1);
        value.setValue("" + (n0 + n1));
        int buf = n0;
        n0 = n1;
        n1 += buf;
        return (Document) doc.copy();
    }
}
