/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package net.sf.xcf.fts.nodes.time;

import java.util.Map;
import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.nodes.filter.AbstractFilter;

/**
 * A delay filter that only passes after a specified delay from the last 
 * trigger.
 *
 * Inputs:
 *   KEY_TRIGGER -- if not present, passes. if present, must contain a timestamp
 *   KEY_TIMEOUT -- if present, overrides the default timeout
 *   + a key for the payload, which this filter doesn't care about
 *
 * @author iluetkeb
 */
@NodeName("TriggeredDelay")
public class TriggeredDelayFilter extends AbstractFilter<Map<String,Object>> {

    public static final String KEY_TRIGGER = "delay.trigger";
    public static final String KEY_TIMEOUT = "delay.timeout";
 
    public static final long DEFAULT_TIMEOUT = 3000;

    private final long standardTimeout;

    /** Create using the default timeout. */
    public TriggeredDelayFilter() {
        this(DEFAULT_TIMEOUT);
    }
    /** Create using the specified timeout (may be overriden by input key). */
    public TriggeredDelayFilter(Long timeout) {
        this.standardTimeout = timeout;
    }

    protected boolean expired(Event<? extends Map<String,Object>> e, long timestamp) {
        final Map<String,Object> map = e.getData();
        long timeout = DEFAULT_TIMEOUT;
        if(map.containsKey(KEY_TIMEOUT)) {
            timeout = (Long)map.get(KEY_TIMEOUT);
        }
        return (System.currentTimeMillis() - timestamp) >= timeout;
    }

    public boolean isMatch(Event<? extends Map<String, Object>> e) throws Exception {
        final Map<String,Object> map = e.getData();
        if(!map.containsKey(KEY_TRIGGER)) {
            return true;
        }
        final Long timestamp = (Long)map.get(KEY_TRIGGER);
        return expired(e, timestamp);

    }

}
