/*
 * Copyright 2009 Bielefeld University
 * Copyright 2009 Patrick Holthaus
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.transform;

import java.io.IOException;
import java.io.OutputStream;
import java.util.logging.Level;
import java.util.logging.Logger;
import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.nodes.sink.BufferOutputEvent;

/**
 *
 * @author pholthau
 */
@NodeName("ConfirmingOutputStreamNode")
public class ConfirmingOutputStreamNode extends AbstractTransformNode<BufferOutputEvent, BufferOutputEvent> {
    
    private final OutputStream os;
    private final Logger log = Logger.getLogger(getClass().getName());
    
    public ConfirmingOutputStreamNode(OutputStream os) {
        this.os = os;
    }

    @Override
    protected BufferOutputEvent transform(BufferOutputEvent evt) {
        try{
            os.write(evt.buf, evt.offset, evt.length);
            os.flush();
            return evt;
        }
        catch(IOException ex){
            log.log(Level.WARNING, "Could not write buffer", ex);
            return evt;
        }
    }
}
