/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.transform;

import java.util.concurrent.ExecutionException;
import java.util.concurrent.Future;
import net.sf.xcf.fts.annotations.NodeName;

/**
 * Node that expects a future and returns its result. This will usually
 * block!
 *
 * @author iluetkeb
 */
@NodeName("FutureGet")
public class FutureGetNode<T> extends AbstractTransformNode<Future<T>, T> {

    public FutureGetNode() {
        super("FutureGetNode");
    }

    /**
     * Calls e.get() and returns it. If an execution exception occurs,
     * it is unpacked and the underlying exception is re-thrown.
     */
    @Override
    protected T transform(Future<T> input) throws Exception {
        try {
            return input.get();
        } catch(ExecutionException ex) {
            throw (Exception)ex.getCause();
        }
    }

}
