/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.transform;

import java.util.ArrayList;
import java.util.List;
import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.Node;
import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.nodes.filter.Filter;

/**
 * Make a list processing node from a single processing node.
 *
 * @author iluetkeb
 */
@NodeName("ForList")
public class GenericListProcessor<TIn,TOut> implements Node<List<TIn>,List<TOut>> {
    private Node<? super TIn,? extends TOut> backend;
    private AbstractTransformNode<? super TIn,? extends TOut> transform;
    private Filter<? super TIn> filter;

    public GenericListProcessor(Node<? super TIn,? extends TOut> backend) {
        this.backend = backend;
    }

    @Override
    public Event<? extends List<TOut>> handleEvent(Event<? extends List<TIn>> evt) throws Exception {
        final List<TIn> input = evt.getData();
        List<TOut> output = new ArrayList<TOut>(input.size());

        for(TIn in : input) {
            Event<? extends TOut> resultEvt = backend.handleEvent(evt.createDerived(in));
            if(resultEvt != null) {
                TOut result = resultEvt.getData();
                if(result != null)
                    output.add(result);
            }
        }
        return evt.createDerived(output);
    }
}
