package net.sf.xcf.fts.nodes.transform;

import java.util.HashMap;

import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.annotations.Transform;
import net.sf.xcf.fts.nodes.AbstractNode;

/**
 * Node that decides the transformation output based on the values of a specified tag.
 * 
 * @author lschilli
 */
@NodeName("MapTransform")
@Transform
public class MapTransformNode<TIn, TOut> extends AbstractNode<TIn, TOut> {

	protected HashMap<Object, TOut> map = new HashMap<Object, TOut>();   
	protected String tagname;
	
	
	public MapTransformNode(String name, String tagname) {
		super(name);
		this.tagname = tagname;
	}
	
	
	@Override
	public Event<? extends TOut> handleEvent(Event<? extends TIn> input)
			throws Exception {
		Object tag = input.getTag(this.tagname);
		return input.createDerived(this.map.get(tag));
	}

	
	public TOut putOutput(Object tagValue, TOut desiredOutput) {
		return this.map.put(tagValue, desiredOutput);
	}

	
}
