/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.transform;

import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.annotations.Filter;
import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.annotations.Transform;
import net.sf.xcf.fts.Node;

/**
 * Checks that input events have the correct tag attached and if they do,
 * returns them with the tag stripped. Otherwise, returns null. *
 *
 * @author iluetkeb
 */
@NodeName("TagMatchStrip")
@Filter
@Transform
public class TagMatchStripNode implements Node {
    private final String tagName;
    private final String tagValue;

    public TagMatchStripNode(String tagName, String tagValue) {
        this.tagName = tagName;
        this.tagValue = tagValue;
    }

    public Event handleEvent(Event input) throws Exception {
        if(tagValue.equals(input.getTag(tagName)))
            return input.removeTags(tagName);
        else
            return null;
    }

    @Override
    public String toString() {
        return "TagStrip";
    }
}
