/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.transform;

import java.util.UUID;
import net.sf.xcf.fts.Event;
import net.sf.xcf.fts.Pair;
import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.annotations.Transform;
import net.sf.xcf.fts.Node;

/**
 * Tags with the give name=value pair, or with a given name and random
 * UUID value.
 *
 * @author iluetkeb
 */
@NodeName("Tag")
@Transform
public class TaggingNode<T> implements Node<T, T> {
    private final Pair<String, Object> tag;

    public TaggingNode(String tagName, Object tagValue) {
        tag = new Pair(tagName, tagValue);
    }

    /** Use given tag name and random UUID value. */
    public TaggingNode(String tagName) {
        this(tagName, UUID.randomUUID());
    }

    @Override
    public Event handleEvent(Event input) throws Exception {
        return input.addTags(tag);
    }

    @Override
    public String toString() {
        return "[" + tag.first + " := " + tag.second + "]";
    }
}
