/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.transform;

import java.util.List;
import net.sf.xcf.fts.annotations.NodeName;
import org.jaxen.JaxenException;
import org.jaxen.XPath;
import org.jaxen.xom.XOMXPath;

/**
 * Returns the result of evaluating an XPath. In contrast to
 * XPathTransformSingleNode, it returns all results.
 *
 * @author iluetkeb
 */
@NodeName("XPathTransform")
public class XPathTransformNode extends AbstractTransformNode<nu.xom.Node, List> {
    private final XPath xpath;

    protected XPathTransformNode() {
        super("XPathTransformNode");
        xpath = null;
    }

    public XPathTransformNode(String xpath) throws JaxenException {
        super("XPathTransformNode: XPath = " + xpath);
        this.xpath = new XOMXPath(xpath);
    }
    public XPathTransformNode(XPath xpath) {
        super("XPathTransformNode: XPath = " + xpath.toString());
        this.xpath = xpath;
    }

    @Override
    protected List transform(nu.xom.Node input) throws Exception {
        return xpath.selectNodes(input);
    }

    @Override
    public String toString() {
        return "XPath[" + xpath + "]";
    }

}
