/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.transform;

import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.annotations.Transform;
import org.jaxen.JaxenException;
import org.jaxen.XPath;
import org.jaxen.xom.XOMXPath;

/**
 * A node that returns the result of matching an XPath and using selectSingleNode.
 * 
 * @author iluetkeb
 */
@NodeName("XPathTransformSingle")
@Transform
public class XPathTransformSingleNode extends AbstractTransformNode<nu.xom.Node, Object> {
    private final XPath xpath;

    protected XPathTransformSingleNode() {
        super("XPathTransformSingleNode");
        xpath = null;
    }

    public XPathTransformSingleNode(String xpath) throws JaxenException {
        super("XPathTransformSingleNode: XPath = " + xpath);
        this.xpath = new XOMXPath(xpath);
    }
    public XPathTransformSingleNode(XPath xpath) {
        super("XPathTransformSingleNode: XPath = " + xpath.toString());
        this.xpath = xpath;
    }

    @Override
    protected Object transform(nu.xom.Node input) throws Exception {
        return xpath.selectSingleNode(input);
    }

    @Override
    public String toString() {
        return "XPath[" + xpath + "]";
    }

}
