/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.transform.io;

import java.awt.image.BufferedImage;
import java.io.File;
import java.io.InputStream;
import java.net.URL;
import javax.imageio.ImageIO;
import javax.imageio.stream.ImageInputStream;
import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.annotations.Transform;
import net.sf.xcf.fts.nodes.transform.AbstractTransformNode;

/**
 *
 * @author ingo
 */
@NodeName("ImageReader")
@Transform
public class ImageLoader extends AbstractTransformNode<Object, BufferedImage> {

    public ImageLoader() {
        super("ImageLoader");
    }

    @Override
    protected BufferedImage transform(Object input) throws Exception {
        if(input instanceof File) {
            return ImageIO.read((File)input);
        } else if(input instanceof ImageInputStream) {
            return ImageIO.read((ImageInputStream)input);
        } else if(input instanceof URL) {
            return ImageIO.read((URL)input);
        } else if(input instanceof InputStream) {
            return ImageIO.read((InputStream)input);
        } else
            throw new IllegalArgumentException("Can only handle input of type" +
                    "File, ImageInputStream, URL and InputStream, not" +
                    input.getClass());
    }


}
