/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.transform.io;

import java.awt.image.RenderedImage;
import java.io.File;
import java.util.Arrays;
import java.util.Map;
import javax.imageio.ImageIO;
import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.nodes.sink.SinkAdapter;

/**
 * Sink that writes an image to a file, both of which must be
 * given in the input map.
 *
 * @author ingo
 */
@NodeName("ImageWriter")
public class ImageWriter extends SinkAdapter<Map<String, Object>> {

    /** Argument specifying file output.  */
    public static final String TAG_FILE = "image.write.file";
    /** Argument specifying the image itself, which must
     * implement RenderedImage.  */
    public static final String TAG_IMAGE = "image.write.image";
    /** Argument specifying the format to use for writing.  */
    public static final String TAG_FORMAT = "image.write.format";

    public ImageWriter() {
        super("ImageWriter");
    }

    @Override
    protected void pushItem(Map<String, Object> e) throws Exception {
        String format = (String)e.get(TAG_FORMAT);
        final File file = (File)e.get(TAG_FILE);
        // when no format is given, try to determine one from the suffix of
        // the filename
        if(format == null) {
            String[] parts = file.getName().split("\\.");
            if(parts.length > 1) {
                format = parts[parts.length -1];
            } else {
                throw new IllegalArgumentException("Missing format and" +
                        " file name (" + file + ")has no suffix");
            }
        }
        ImageIO.write((RenderedImage)e.get(TAG_IMAGE), format, file);
    }

    /** Small runnable to figure out what the known formats are. */
    public static void main(String []args) {
        System.out.println("read formats: " + Arrays.asList(ImageIO.getReaderFormatNames()));
        System.out.println("read suffixes: " + Arrays.asList(ImageIO.getReaderFileSuffixes()));
        System.out.println("read mime types: " + Arrays.asList(ImageIO.getReaderMIMETypes()));
        System.out.println("write formats: " + Arrays.asList(ImageIO.getWriterFormatNames()));
        System.out.println("write suffixes: " + Arrays.asList(ImageIO.getWriterFileSuffixes()));
        System.out.println("write suffixes: " + Arrays.asList(ImageIO.getWriterMIMETypes()));
    }


}
