/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.transform.io;

import java.io.IOException;
import java.io.InputStream;
import java.util.logging.Level;
import java.util.logging.Logger;
import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.nodes.sink.SinkAdapter;

/**
 * Writes output to an external Process. This class will also
 * read the output and error stream of the external process every
 * time input is fed to it. Output is logged with level INFO, errors are
 * logged with level WARNING.
 *
 * @author ingo
 */
@NodeName("PipeProcessSink")
public class PipeProcessSink extends SinkAdapter {
    private final Logger logger = Logger.getLogger(PipeProcessSink.class.getName());

    private final Process process;
    
    public PipeProcessSink(String command) throws IOException {
        super(command);
        process = Runtime.getRuntime().exec(command);
    }

    protected void logAvailable(Level level, InputStream in) throws IOException {
        if(in.available() > 0) {
            byte[] buf = new byte[1024];
            // get currently available number of bytes. do not recheck to
            // prevent staying in method forever
            StringBuffer sb = new StringBuffer();
            final int length = in.available();
            int count = 0;
            int nread = 0;
            while(count < length) {
                nread = in.read(buf);
                count+=nread;
                sb.append(new String(buf, 0, nread));

            }
            logger.log(level, sb.toString());
        }
    }

    @Override
    protected void pushItem(Object e) throws Exception {
        process.getOutputStream().write(e.toString().getBytes());
        logAvailable(Level.INFO, process.getInputStream());
        logAvailable(Level.WARNING, process.getErrorStream());
    }

}
