/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.transform.xml;

import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.nodes.transform.AbstractTransformNode;
import nu.xom.Element;

/**
 * Appends a child element with the specified name to the input Element
 * and returns the child.
 *
 * @author iluetkeb
 */
@NodeName("AddChildElement")
public class AddChildElementTransform extends AbstractTransformNode<Element,Element> {
    private final Element child;

    public AddChildElementTransform(String name) {
        this(name, null);
    }
    public AddChildElementTransform(String name, String namespaceURI) {
        if(name == null)
            throw new NullPointerException("Name must not be null");
        if(namespaceURI == null)
            child = new Element(name);
        else
            child = new Element(name, namespaceURI);
    }

    @Override
    protected Element transform(Element input) throws Exception {
        Element newChild = (Element) child.copy();
        input.appendChild(newChild);
        return newChild;
    }
}
