/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.transform.xml;

import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.nodes.transform.AbstractTransformNode;
import nu.xom.Element;

/**
 *
 * @author iluetkeb
 */
@NodeName("InsertChildElement")
public class InsertChildElementTransform extends AbstractTransformNode<Element,Element> {
    private final Element child;
    private final int position;

    public InsertChildElementTransform(String name, Integer position) {
        this(name, null, position);
    }
    public InsertChildElementTransform(String name, String namespaceURI, Integer position) {
        if(name == null)
            throw new NullPointerException("Name must not be null");
        if(position < 0)
            throw new IllegalArgumentException("Position must be positive");
        if(namespaceURI == null)
            child = new Element(name);
        else
            child = new Element(name, namespaceURI);
        this.position = position;
    }

    @Override
    protected Element transform(Element input) throws Exception {
        Element newChild = (Element) child.copy();
        input.insertChild(newChild, position);
        return newChild;
    }
}
