/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.xcf.fts.nodes.transform.xml;

import java.util.Map;
import java.util.logging.Logger;
import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.nodes.transform.AbstractTransformNode;
import nu.xom.Attribute;
import nu.xom.Element;

/**
 * Adds attribute with value dynamically passed in.
 * 
 * @author iluetkeb
 */
@NodeName("SetDynamicAttribute")
public class SetDynamicAttributeTransform extends AbstractTransformNode<Map<String, Object>, Element> {

    private static final Logger logger = Logger.getLogger(SetDynamicAttributeTransform.class.getName());
    private final Attribute attr;
    public static final String KEY_ELEMENT = "xml.attribute.element";
    public static final String KEY_VALUE = "xml.attribute.value";

    public static final String DEF_VALUE = "";

    public SetDynamicAttributeTransform(String name) {
        this(name, null);
    }
    public SetDynamicAttributeTransform(String name, String namespaceURI) {
        if(name == null)
            throw new NullPointerException("Null name not allowed");
        if(namespaceURI == null)
            attr = new Attribute(name, DEF_VALUE);
        else
            attr = new Attribute(name, namespaceURI, DEF_VALUE);
    }

    @Override
    protected Element transform(Map<String, Object> input) throws Exception {
        Attribute newAttr = (Attribute) attr.copy();
        Object value = input.get(KEY_VALUE);
        Element parent = (Element)input.get(KEY_ELEMENT);

        if (value == null) {
            logger.warning(KEY_VALUE + " had no value");
            return null;
        }
        if(parent == null) {
            logger.warning(KEY_ELEMENT + " had no value");
            return null;

        }
        newAttr.setValue(input.get(KEY_VALUE).toString());
        parent.addAttribute(newAttr);
        return parent;
    }
}
