/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle <ingo@fargonauten.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.fts.nodes.transform.xml;

import net.sf.xcf.fts.annotations.NodeName;
import net.sf.xcf.fts.nodes.transform.AbstractTransformNode;
import nu.xom.Attribute;
import nu.xom.Element;

/**
 * Add attribute with given name and value, optional namespaces.
 *
 * @author iluetkeb
 */
@NodeName("SetStaticAttribute")
public class SetStaticAttributeTransform extends AbstractTransformNode<Element,Element> {
    private final Attribute attr;

    public SetStaticAttributeTransform(String attributeName, String attributeValue) {
        this(attributeName, null, attributeValue);
    }
    public SetStaticAttributeTransform(String attributeName, String namespaceURI, String attributeValue) {
        if(attributeName == null || attributeValue == null)
            throw new NullPointerException("Illegal (non-null) args, got " +
                    "name=" + attributeName + ", value=" + attributeValue);
        if(namespaceURI == null)
            attr = new Attribute(attributeName, attributeValue);
        else
            attr = new Attribute(attributeName, namespaceURI, attributeValue);
    }

    @Override
    protected Element transform(Element input) throws Exception {
        input.addAttribute((Attribute) attr.copy());
        return input;
    }

}
