/*
 * Copyright 2008, 2009 Bielefeld University
 * Copyright 2008, 2009 Ingo Luetkebohle, Sebastian Wrede, Jan Schaefer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.xcf.tools.fts.pmatch.xpath;

import javax.xml.namespace.NamespaceContext;
import javax.xml.namespace.QName;
import javax.xml.xpath.XPathExpressionException;
import javax.xml.xpath.XPathFunctionResolver;
import javax.xml.xpath.XPathVariableResolver;
import nu.xom.Document;
import nu.xom.XPathException;
import org.jaxen.JaxenException;
import org.jaxen.expr.Expr;
import org.jaxen.xom.XOMXPath;
import org.xml.sax.InputSource;


/**
 * Represents an internal to used xpath, which encapsulates
 * Jaxen and XOM object behaviour. This is done with regard
 * to easy to use XML information.
 * 
 * @author mwesterm
 */
public class XPath implements javax.xml.xpath.XPath {
	
	private NamespaceContext nameSpaceContext;

	private XOMXPath xomPath;
	
	/**
	 * Constructs a XPath without a namespace.
	 * 
	 * @param xpath  String, the xpath 
	 */
	public XPath(String xpath) {
		this.xomPath = null;
		parseXPath(xpath);
	}	
	
	/**
	 * Constructs a XPath with a given source.
	 * 
	 * @param xpath  XPath, the xpath for this new instance
	 * @param nameSpace  NamespaceContext, the source where to perform xpath queries
	 */
	public XPath(String xpath, NamespaceContext nameSpace) {
		this.nameSpaceContext = nameSpace;
		parseXPath(xpath);
	}	

        org.jaxen.xom.XOMXPath getCompiledXPath() {
            return this.xomPath;
        }
        
	public NamespaceContext getCtx() {
		return null;
	}

	public void setCtx(NamespaceContext ctx) {
		throw new UnsupportedOperationException();
	}

	public String getExpression() {
		return this.xomPath.toString();
	}
	
	public void setExpression(String expression) {
		parseXPath(expression);
	}
	
	public boolean hasFilterOnRoot(String filter) {
		Expr expr = this.xomPath.getRootExpr();
		String expression = expr.getText();
		int rootEnd = expression.indexOf("/", 1);
		if (rootEnd == -1){
			rootEnd = expression.length();
		}
		String root = expression.substring(0, rootEnd-1);
		String filterContent = filter.substring(1, filter.length()-1);
		if (root.contains(filterContent)) {
			return true;
		}
		return false;
	}
	
	private void parseXPath(String xpath) {
		try {
			this.xomPath = new XOMXPath(xpath);
                        if(this.nameSpaceContext != null) {
                            
                            this.xomPath.setNamespaceContext((org.jaxen.NamespaceContext) this.nameSpaceContext);
                        }
		} catch (JaxenException e) {
			throw new XPathException(e.getMessage());
		}
	}

	
	public boolean match(Document document) {
		if (document == null) {
			return false;
		}
                try {
                        return this.xomPath.selectSingleNode(document) != null;
                } catch (JaxenException ex) {
                        return false;
                }
	}

	public javax.xml.xpath.XPathExpression compile(String expression) throws XPathExpressionException {
		// TODO Auto-generated method stub
		return null;
	}

	public String evaluate(String expression, Object item) throws XPathExpressionException {
		// TODO Auto-generated method stub
		return null;
	}

	public String evaluate(String expression, InputSource source) throws XPathExpressionException {
		// TODO Auto-generated method stub
		return null;
	}

	public Object evaluate(String expression, Object item, QName returnType) throws XPathExpressionException {
		// TODO Auto-generated method stub
		return null;
	}

	public Object evaluate(String expression, InputSource source, QName returnType) throws XPathExpressionException {
		// TODO Auto-generated method stub
		return null;
	}

	public NamespaceContext getNamespaceContext() {
		// TODO Auto-generated method stub
		return null;
	}

	public XPathFunctionResolver getXPathFunctionResolver() {
		// TODO Auto-generated method stub
		return null;
	}

	public XPathVariableResolver getXPathVariableResolver() {
		// TODO Auto-generated method stub
		return null;
	}

	public void reset() {
		// TODO Auto-generated method stub
		throw new UnsupportedOperationException();
	}

	public void setNamespaceContext(NamespaceContext nsContext) {
		// TODO Auto-generated method stub
		throw new UnsupportedOperationException();
	}

	public void setXPathFunctionResolver(XPathFunctionResolver resolver) {
		// TODO Auto-generated method stub
		throw new UnsupportedOperationException();
	}

	public void setXPathVariableResolver(XPathVariableResolver resolver) {
		// TODO Auto-generated method stub
		throw new UnsupportedOperationException();
	}
}
